diff --git a/CHANGES.md b/CHANGES.md
index 743f5066..7cb03c30 100644
--- a/CHANGES.md
+++ b/CHANGES.md
@@ -3,8 +3,11 @@
 ## Unreleased - 2021-xx-xx
 ### Changed
 * Feature `cookies` is now optional and enabled by default. [#1981]
+* `JsonBody::new` returns a default limit of 32kB to be consistent with `JsonConfig` and the
+  default behaviour of the `web::Json<T>` extractor. [#2010] 
 
 [#1981]: https://github.com/actix/actix-web/pull/1981
+[#2010]: https://github.com/actix/actix-web/pull/2010
 
 
 ## 4.0.0-beta.3 - 2021-02-10
diff --git a/src/types/json.rs b/src/types/json.rs
index 28960402..31ff680f 100644
--- a/src/types/json.rs
+++ b/src/types/json.rs
@@ -345,7 +345,7 @@ where
         let payload = payload.take();
 
         JsonBody::Body {
-            limit: 262_144,
+            limit: 32_768,
             length,
             payload,
             buf: BytesMut::with_capacity(8192),
@@ -353,7 +353,7 @@ where
         }
     }
 
     /// Set maximum accepted payload size. The default limit is 256kB.
     pub fn limit(self, limit: usize) -> Self {
         match self {
             JsonBody::Body {
@@ -353,7 +353,7 @@ where
     }
 
-    /// Set maximum accepted payload size. The default limit is 256kB.
+    /// Set maximum accepted payload size. The default limit is 32kB.
     pub fn limit(self, limit: usize) -> Self {
         match self {